@@ -4,7 +4,7 @@ from pyinterpolate.distance.calculate_distances import calc_point_to_point_dista
 from pyinterpolate.transform.select_values_in_range import select_values_in_range
 
 
-def calculate_covariance(data, lags, step_size):
+def calculate_covariance(data, step_size, max_range):
     """Function calculates covariance of a given set of points.
 
         Equation for calculation is:
@@ -22,8 +22,8 @@ def calculate_covariance(data, lags, step_size):
         INPUT:
 
         :param data: (numpy array) coordinates and their values,
-        :param lags: (numpy array) lags between points,
-        :param step_size: (float) distance between lags within each points are included in the distance.
+        :param step_size: (float) step size of circle within radius are analyzed points,
+        :param max_range: (float) maximum range of analysis.
 
         OUTPUT:
 
@@ -40,6 +40,8 @@ def calculate_covariance(data, lags, step_size):
     covar = []
     covariance = []
 
+    lags = np.arange(0, max_range, step_size)
+
     for idx, h in enumerate(lags):
         distances_in_range = select_values_in_range(distances, h, step_size)
         cov = (data[distances_in_range[0], 2] * data[distances_in_range[1], 2])
