@@ -1,4 +1,4 @@
 from .get_areal_centroids import get_centroids
 from .prepare_kriging_data import prepare_kriging_data, prepare_poisson_kriging_data, prepare_ata_data, prepare_atp_data
-from .select_values_in_range import select_values_in_range
-from .set_areal_weights import set_areal_weights
\ No newline at end of file
+from .select_values_in_range import select_values_in_range, check_points_within_ellipse
+from .set_areal_weights import set_areal_weights
